pub fn create_network(count: usize) -> Vec<MemoryTransport>Expand description
Create a fully connected in-memory transport network.
Each peer is connected to every other peer, making this helper ideal for deterministic tests and examples.
pub fn create_network(count: usize) -> Vec<MemoryTransport>Create a fully connected in-memory transport network.
Each peer is connected to every other peer, making this helper ideal for deterministic tests and examples.